@@ -7,7 +7,7 @@ import { ReactNode } from 'react';
 import { render } from 'react-dom';
 
 import { Calendar } from '@/components/Calendar';
-import { Close, Menu, Search } from '@/components/icons';
+import { Close, Menu, PlusIcon, Search } from '@/components/icons';
 import { theme } from '@/theme';
 
 function MaterialUIProvider({ children }: { children: ReactNode }) {
@@ -90,8 +90,6 @@ function highlightActivePageTocItem() {
     );
     const firstHeaderInViewport = headers[firstHeaderIndex];
 
-    if (!firstHeaderInViewport) return;
-
     if (lastLinkClicked) {
       activeHeaderIndex =
         headers.findIndex(
@@ -100,6 +98,8 @@ function highlightActivePageTocItem() {
             lastLinkClicked?.getAttribute('href')?.slice(1),
         ) ?? null;
       activeHeader = headers.at(activeHeaderIndex) ?? null;
+    } else if (!firstHeaderInViewport) {
+      return;
     } else if (
       firstHeaderInViewport.getBoundingClientRect().top <
       appBarHeight + 16 + 32
@@ -340,14 +340,27 @@ function renderCalendars() {
     document.querySelectorAll('.napari-calendar'),
   );
 
-  calendarNodes.forEach((node) =>
-    render(
-      <MaterialUIProvider>
-        <Calendar filter={node.classList.contains('show-filters')} />
-      </MaterialUIProvider>,
-      node,
-    ),
-  );
+  calendarNodes.forEach((node) => {
+    const calendarID = Array.from(node.classList)
+      .map((className) =>
+        className.startsWith('calendar-id')
+          ? className.split('calendar-id-')[1]
+          : undefined,
+      )
+      .find(Boolean);
+
+    if (calendarID) {
+      render(
+        <MaterialUIProvider>
+          <Calendar
+            calendarID={calendarID}
+            filter={node.classList.contains('show-filters')}
+          />
+        </MaterialUIProvider>,
+        node,
+      );
+    }
+  });
 }
 
 function fixSearchInput() {
@@ -505,6 +518,20 @@ function addAutoLoopAndControlsToVideos() {
   });
 }
 
+/**
+ * Fixes issue with admonition dropdowns showing empty white space when hidden:
+ * https://github.com/napari/napari-sphinx-theme/issues/99
+ */
+function renderDropdownButtonIcons() {
+  const buttons = Array.from(
+    document.querySelectorAll('.dropdown.admonition .toggle-button'),
+  );
+
+  for (const button of buttons) {
+    render(<PlusIcon />, button);
+  }
+}
+
 function main() {
   addInPageTocInteractivity();
   highlightActivePageTocItem();
@@ -516,6 +543,7 @@ function main() {
   renderAppBarMenuButton();
   addClassToCodeBlocksWithLineNumbers();
   addAutoLoopAndControlsToVideos();
+  renderDropdownButtonIcons();
   // Wrap in setTimeout so that it runs after sphinx search JS.
   setTimeout(fixSearchInput);
   setTimeout(fixSearchContainer);
